@@ -165,6 +165,17 @@ def symbols_get(*,
     :return: A tuple of SymbolInfo objects
     """
     symbols = _mt5.symbols_get(group=group) if group else _mt5.symbols_get()
+    if symbols is None and _state.raise_on_errors:
+        build = version()
+        if build:
+            if build[1] < _const.MIN_TERMINAL_BUILD :
+                raise MT5Error(_const.RES_X_TERMINAL_VERSION_OUTDATED,
+                               "The terminal build needs to be updated to support this feature.")
+        else:
+            error_code, des = last_error()
+            if error_code == _const.RES_S_OK:
+                raise MT5Error(_const.RES_X_UNKNOWN_ERROR,
+                               "Unknown Error. Is the terminal connected?")
     if regex:
         if isinstance(regex, str):
             regex = re.compile(regex)
